Date: 07 31, 2001 11:01:48 AM

# debug

## Purpose

Pre action that succeeds unconditionally. Used to place a C++ breakpoint at a particular rule.

## Syntax

<fromRuleEltNumber,toRuleEltNumber>debug;

fromRuleEltNumber - type: int
toRuleEltNumber - type: int

## Returns

## Remarks

debug can appear in the PRE, CHECK and POST regions.

## Example

@PRE
<1,1> debug();

@RULES

_xNIL <- _xALPHA @@

## See Also

Special Functions, PRE Actions